@@ -5,6 +5,7 @@ import re
 import urllib
 from django import template
 from django.conf import settings
+from django.contrib.contenttypes.models import ContentType
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db.models import DateField, Count, Sum
 from django.db.models.functions import TruncDay
@@ -23,19 +24,19 @@ register = template.Library()
 def translate_url(context, lang, *args, **kwargs):
     path = kwargs.get('path', None)
     object = kwargs.get('object', None)
-    callable = kwargs.get('callable', None)
+    callable_object = kwargs.get('callable', None)
 
-    if path and (object or callable):
+    if path and (object or callable_object):
         raise ValueError('"path" argument can not be used together with "object" or "callable"')
 
-    if object and not callable or callable and not object:
+    if object and not callable_object or callable_object and not object:
         raise ValueError('Both "object" or "callable" has to be defined')
 
     if not path:
         # custom object
         if object:
             with override_language(lang):
-                path = getattr(object, callable)()
+                path = getattr(object, callable_object)()
                 return django_translate_url(path, lang)
 
         # context object
@@ -43,10 +44,15 @@ def translate_url(context, lang, *args, **kwargs):
 
         if context_object:
             with override_language(lang):
-                return context_object.get_absolute_url()
+                get_absolute_url = getattr(context_object, "get_absolute_url", None)
+
+                if get_absolute_url and callable(get_absolute_url):
+                    return context_object.get_absolute_url()
 
         # URL path
-        path = context['request'].path
+        # path = context['request'].path
+        request = context.get('request', None)
+        path = request.path if request else f'/{lang}/'
 
     return django_translate_url(path, lang)
 
@@ -635,6 +641,12 @@ def add_days(days):
     return now() + datetime.timedelta(days=days)
 
 
+@register.filter
+def add_months(months):
+    from dateutil.relativedelta import relativedelta
+    return now() + relativedelta(months=months)
+
+
 @register.filter(is_safe=False)
 def concat(value, arg):
     """Add the arg to the value."""
@@ -683,3 +695,15 @@ def date_from_isoformat(date_string):
 def values_list(qs, attrs):
     attributes = attrs.split(',')
     return qs.values_list(*attributes, flat=True)
+
+
+@register.filter()
+def get_objects_by_ids(ids, model):
+    ids_list = ids.split(',')
+    content_type = ContentType.objects.get_by_natural_key(*model.split('.'))
+
+    if not content_type:
+        return None
+
+    objects = content_type.model_class().objects.filter(id__in=ids_list)
+    return ', '.join(str(obj) for obj in objects.all())
